---
name: Bug report
about: Create a report and help this package improve
title: 'bug: '
labels: bug
assignees: ''
---
<!-- This template is a suggestion. So, you do not have to use it. -->

**Describe the bug**
<!-- A clear and concise description of what the bug is. -->

**To Reproduce**
<!-- Source code to reproduce the behavior. -->

**ICS file**
<!-- Please paste an ICS file here which does not work or attach it with a .txt ending. -->

```ics
```

**Expected behavior**
<!-- A clear and concise description of what you expected to happen. -->

**Console output**
<!-- If applicable, add output/screenshots to help explain your problem. -->

**Version:**
<!-- Which Version do you use? -->
![](https://raster.shields.io/badge/version-3.3.0-brightgreen.png)

<!-- Sometimes, the problems are in other packages. You can provide an overview
     by running this command and passing the output:

     pip list
-->
```shell
pip list
```

**Additional context**
<!-- Add any other context about the problem here. Or maybe related issues. -->

**Suggested implementation**
<!-- If possible, suggest a way of solving this or just let this text down there remain as it is. -->

- [ ] add an ICS file, example:
    https://github.com/niccokunzmann/python-recurring-ical-events/blob/f4a90b211f30bf0522f03514ba50eb69826f0fdb/test/calendars/issue-15-duplicated-events.ics#L1
- [ ] add a test, example:
    https://github.com/niccokunzmann/python-recurring-ical-events/blob/f4a90b211f30bf0522f03514ba50eb69826f0fdb/test/test_issue_15.py#L21
- [ ] fix the bug and ensure the test code passes
